@@ -66,12 +66,26 @@ def tox_add_option(parser):
         help="Don't run tests, only print the names of the required dependency-groups to the given file "
         + "(use `-` for stdout)",
     )
+    parser.add_argument(
+        "--assert-config",
+        action="store_true",
+        default=False,
+        help="Fail if no tox configuration is found",
+    )
 
 
 @impl
 def tox_add_core_config(core_conf, state):
     opt = state.conf.options
 
+    if opt.assert_config and not state.conf.src_path.exists():
+        raise LookupError(
+            "tox configuration not found. "
+            "To use tox, please ensure tox configuration is located in current directory "
+            "(in tox.ini, setup.cfg, pyproject.toml, or tox.toml). "
+            "See https://tox.wiki/en/latest/config.html for details."
+        )
+
     if opt.current_env or opt.print_deps_to or opt.print_extras_to or opt.print_dependency_groups_to:
         # We do not want to install the main package.
         # no_package is the same as skipsdist.
@@ -93,10 +107,6 @@ def tox_add_core_config(core_conf, state):
         opt.default_runner = "print-env"
         return
 
-    # No options used - switch back to the standard runner
-    # Workaround for: https://github.com/tox-dev/tox/issues/2264
-    opt.default_runner = "virtualenv"
-
 
 @impl
 def tox_add_env_config(env_conf, state):
